@@ -1,14 +1,12 @@
-package Class::Load::PP;
-{
-  $Class::Load::PP::VERSION = '0.13';
-}
-
 use strict;
 use warnings;
+package Class::Load::PP;
+$Class::Load::PP::VERSION = '0.22';
 use Module::Runtime 'is_module_name';
-use Package::Stash;
+use Package::Stash 0.14;
 use Scalar::Util 'blessed', 'reftype';
 use Try::Tiny;
+use namespace::clean;
 
 sub is_class_loaded {
     my $class   = shift;
